Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(523)

Unified Diff: pkg/analysis_server/test/integration/search/test_all.dart

Issue 458453003: Split up server_domain_int_test.dart; regularize integration test directories. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Update status file Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/analysis_server/test/integration/search/test_all.dart
diff --git a/pkg/analysis_services/test/search/test_all.dart b/pkg/analysis_server/test/integration/search/test_all.dart
similarity index 57%
copy from pkg/analysis_services/test/search/test_all.dart
copy to pkg/analysis_server/test/integration/search/test_all.dart
index 86364491209dae7ac9f4dd6073c862b217027724..e3c4459fb95f5b365b910b54996bed8967fa2f4e 100644
--- a/pkg/analysis_services/test/search/test_all.dart
+++ b/pkg/analysis_server/test/integration/search/test_all.dart
@@ -2,21 +2,18 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
-library test.services.src.search.all;
+library test.integration.search.all;
import 'package:unittest/unittest.dart';
-import 'hierarchy_test.dart' as hierarchy_test;
-import 'search_engine_test.dart' as search_engine_test;
-
+import 'get_type_hierarchy_test.dart' as get_type_hierarchy_test;
/**
* Utility for manually running all tests.
*/
main() {
groupSep = ' | ';
group('search', () {
- hierarchy_test.main();
- search_engine_test.main();
+ get_type_hierarchy_test.main();
});
}
@@ -2,21 +2,18 @@
/**
- * Utility for manually running all tests.
+ * Utility for manually running all integration tests.
*/
main() {

Powered by Google App Engine
This is Rietveld 408576698